/*
 * BasicStatsReportingTest.java
 *
 * Copyright (c) 2005 TopCoder, Inc., All Rights Reserved
 */
package com.topcoder.file.statistics;

import com.topcoder.file.statistics.matcher.TextFileMatcher;
import com.topcoder.file.statistics.processor.linecounter.CStyleLineCounter;
import com.topcoder.file.statistics.processor.linecounter.TextLineCounter;
import com.topcoder.file.statistics.reporting.BasicStatsReporting;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.io.File;


/**
 * Unit tests for BasicStatsReporting implementation.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class BasicStatsReportingTest extends TestCase {
    /**
     * The file storing the correct report format.
     */
    private static final String REPORT_FILE = "test_files/basic.txt";

    /**
     * The path of the base directory used in the reporting.
     */
    private static final String BASE_DIRECTORY = "test_files/";

    /**
     * The BasicStatsReporting instance to test against.
     */
    private BasicStatsReporting reporting = null;

    /**
     * The base directory used in the reporting.
     */
    private File baseDirectory = null;

    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(BasicStatsReportingTest.class);

        return suite;
    }

    /**
     * Prepares a BasicStatsReporting instance for testing. Also prepares the associated base directory.
     */
    public void setUp() {
        reporting = new BasicStatsReporting();
        baseDirectory = new File(BASE_DIRECTORY);
    }

    /**
     * Tests the accessibility of default constructor.
     */
    public void testConstructor_Default() {
        new BasicStatsReporting();
    }

    /**
     * Test of constructor with null property. Expects NullPointerException.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public void testConstructor_NullProperty() throws Exception {
        try {
            new BasicStatsReporting(null);
            fail("Creates BasicStatsReporting with null property");
        } catch (NullPointerException e) {
            // good
        }
    }

    /**
     * Test of generateReport method. First, aggregates some results by processing the files "test_files/a/q.java" and
     * "test_files/b/test.sql" using the processors TextLineCounter and CStyleLineCounter. Verifies if it generates
     * the report in the format stored in "test_files/basic.txt".
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public void testGenerateReport() throws Exception {
        reporting.reset(baseDirectory);

        // aggregate the result for "test_files/b/test.sql"
        FileProcessor processor = new TextLineCounter("Text File", new TextFileMatcher());
        File file = new File("test_files/b/test.sql");
        StatsResult result = processor.process(file);

        reporting.aggregate(processor, file, result);

        // aggregate the result for "test_files/a/q.java"
        processor = new CStyleLineCounter("Source File", new TextFileMatcher());
        file = new File("test_files/a/q.java");
        result = processor.process(file);

        reporting.aggregate(processor, file, result);

        assertTrue("Generates an incorrect report",
            TestHelper.verifyReport(new File(REPORT_FILE), reporting.generateReport()));
    }
}
