/*
 * ConfigHelper.java
 *
 * Copyright (c) 2005 TopCoder, Inc., All Rights Reserved
 */
package com.topcoder.file.statistics;

import com.topcoder.util.config.ConfigManager;
import com.topcoder.util.config.Property;

import java.util.Iterator;


/**
 * A helper class to set up all the configuration namespaces for testing.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class ConfigHelper {
    /**
     * The configuration file for testing good Property objects.
     */
    public static final String GOOD_PROPERTY_CONFIG_FILE = "good_property.xml";

    /**
     * The configuration file for testing bad Property objects.
     */
    public static final String BAD_PROPERTY_CONFIG_FILE = "bad_property.xml";

    /**
     * The namespace to get the good Property object for ExtensionMatcher.
     */
    public static final String GOOD_EXTENSION_MATCHER_NAMESPACE =
        "com.topcoder.file.statistics.matcher.GoodExtensionMatcher";

    /**
     * The namespace to get the bad Property object for ExtensionMatcher.
     */
    public static final String BAD_EXTENSION_MATCHER_NAMESPACE =
        "com.topcoder.file.statistics.matcher.BadExtensionMatcher";

    /**
     * The namespace to get the good Property object for RegexMatcher.
     */
    public static final String GOOD_REGEX_MATCHER_NAMESPACE =
        "com.topcoder.file.statistics.matcher.GoodRegexMatcher";

    /**
     * The namespace to get the bad Property object for RegexMatcher.
     */
    public static final String BAD_REGEX_MATCHER_NAMESPACE =
        "com.topcoder.file.statistics.matcher.BadRegexMatcher";

    /**
     * The namespace to get the good Property object for MimeMatcher.
     */
    public static final String GOOD_MIME_MATCHER_NAMESPACE =
        "com.topcoder.file.statistics.matcher.GoodMimeMatcher";

    /**
     * The namespace to get the bad Property object for MimeMatcher.
     */
    public static final String BAD_MIME_MATCHER_NAMESPACE =
        "com.topcoder.file.statistics.matcher.BadMimeMatcher";

    /**
     * The namespace to get the good Property object for TypeNameMatcher.
     */
    public static final String GOOD_TYPE_NAME_MATCHER_NAMESPACE =
        "com.topcoder.file.statistics.matcher.GoodTypeNameMatcher";

    /**
     * The namespace to get the bad Property object for TypeNameMatcher.
     */
    public static final String BAD_TYPE_NAME_MATCHER_NAMESPACE =
        "com.topcoder.file.statistics.matcher.BadTypeNameMatcher";

    /**
     * The namespace to get the good Property object for FileProcessorBase.
     */
    public static final String GOOD_FILE_PROCESSOR_BASE_NAMESPACE =
        "com.topcoder.file.statistics.matcher.GoodFileProcessorBase";

    /**
     * The namespace to get the bad Property object for FileProcessorBase.
     */
    public static final String BAD_FILE_PROCESSOR_BASE_NAMESPACE =
        "com.topcoder.file.statistics.matcher.BadFileProcessorBase";

    /**
     * The namespace to get the good Property object for XmlStatsReporting.
     */
    public static final String GOOD_XML_STATS_REPORTING_NAMESPACE =
        "com.topcoder.file.statistics.reporting.GoodXmlStatsReporting";

    /**
     * The namespace to get the bad Property object for XmlStatsReporting.
     */
    public static final String BAD_XML_STATS_REPORTING_NAMESPACE =
        "com.topcoder.file.statistics.reporting.BadXmlStatsReporting";

    /**
     * The namespace to get the good Property object for FileStatistics.
     */
    public static final String GOOD_FILE_STATISTICS_NAMESPACE =
        "com.topcoder.file.statistics.GoodFileStatistics";

    /**
     * The namespace to get the bad Property object for FileStatistics.
     */
    public static final String BAD_FILE_STATISTICS_NAMESPACE =
        "com.topcoder.file.statistics.BadFileStatistics";

    /**
     * Private constructor to prevent instantiation.
     */
    private ConfigHelper() {
    }

    /**
     * Loads the namespaces of all the configuration files.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public static void loadConfig() throws Exception {
        ConfigManager config = ConfigManager.getInstance();

        config.add(GOOD_PROPERTY_CONFIG_FILE);
        config.add(BAD_PROPERTY_CONFIG_FILE);
    }

    /**
     * Clears all the namespaces.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public static void unloadConfig() throws Exception {
        ConfigManager config = ConfigManager.getInstance();

        for (Iterator i = config.getAllNamespaces(); i.hasNext();) {
            config.removeNamespace((String) i.next());
        }
    }

    /**
     * Gets the root property of the specified namespace.
     *
     * @param namespace the namespace to get the root property from.
     *
     * @return the root property.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public static Property getRootProperty(String namespace)
        throws Exception
    {
        return ConfigManager.getInstance().getPropertyObject(namespace, "");
    }
}
