/*
 * TextFileMatcherTest.java
 *
 * Copyright (c) 2005 TopCoder, Inc., All Rights Reserved
 */
package com.topcoder.file.statistics;

import com.topcoder.file.statistics.matcher.TextFileMatcher;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.io.File;


/**
 * Unit tests for TextFileMatcher implementation.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class TextFileMatcherTest extends TestCase {
    /**
     * The binary file for testing.
     */
    private static final String BINARY_FILE = "test_files/a/q.class";

    /**
     * The text file for testing.
     */
    private static final String TEXT_FILE = "test_files/b/test.xml";

    /**
     * The TextFileMatcher instance to test against.
     */
    private TextFileMatcher matcher = null;

    /**
     * Creates a test suite for the tests in this test case.
     *
     * @return a TestSuite for this test case
     */
    public static Test suite() {
        TestSuite suite = new TestSuite(TextFileMatcherTest.class);

        return suite;
    }

    /**
     * Prepares an TextFileMatcher instance for testing.
     */
    public void setUp() {
        matcher = new TextFileMatcher();
    }

    /**
     * Tests the accessibility of default constructor.
     */
    public void testConstructor_Default() {
        new TextFileMatcher();
    }

    /**
     * Test of constructor with null property. Expects NullPointerException.
     */
    public void testConstructor_NullProperty() {
        try {
            new TextFileMatcher(null);
            fail("Creates TextFileMatcher with null property");
        } catch (NullPointerException e) {
            // good
        }
    }

    /**
     * Test of match method with binary file. Verifies if false is returned.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public void testMatch_BinaryFile() throws Exception {
        assertFalse("Returns true with binary file", matcher.match(new File(BINARY_FILE)));
    }

    /**
     * Test of match method with text file. Verifies if true is returned.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public void testMatch_TextFile() throws Exception {
        assertTrue("Returns false with text file", matcher.match(new File(TEXT_FILE)));
    }
}
